diff --git a/src/pcm_convert.h b/src/pcm_convert.h
index 35bbdad5c..b22731e08 100644
--- a/src/pcm_convert.h
+++ b/src/pcm_convert.h
@@ -33,7 +33,7 @@ struct audio_format;
 struct pcm_convert_state {
 	struct pcm_resample_state resample;
 
-	struct pcm_dither_24 dither;
+	struct pcm_dither dither;
 
 	/** the buffer for converting the sample format */
 	struct pcm_buffer format_buffer;
diff --git a/src/pcm_dither.c b/src/pcm_dither.c
index 2b4c8ab50..c6f10dd30 100644
--- a/src/pcm_dither.c
+++ b/src/pcm_dither.c
@@ -20,7 +20,7 @@
 #include "pcm_prng.h"
 
 static int16_t
-pcm_dither_sample_24_to_16(int32_t sample, struct pcm_dither_24 *dither)
+pcm_dither_sample_24_to_16(int32_t sample, struct pcm_dither *dither)
 {
 	int32_t output, rnd;
 
@@ -69,7 +69,7 @@ pcm_dither_sample_24_to_16(int32_t sample, struct pcm_dither_24 *dither)
 }
 
 void
-pcm_dither_24_to_16(struct pcm_dither_24 *dither,
+pcm_dither_24_to_16(struct pcm_dither *dither,
 		    int16_t *dest, const int32_t *src,
 		    unsigned num_samples)
 {
diff --git a/src/pcm_dither.h b/src/pcm_dither.h
index cda81e034..b0c0304ee 100644
--- a/src/pcm_dither.h
+++ b/src/pcm_dither.h
@@ -21,20 +21,20 @@
 
 #include <stdint.h>
 
-struct pcm_dither_24 {
+struct pcm_dither {
 	int32_t error[3];
 	int32_t random;
 };
 
 static inline void
-pcm_dither_24_init(struct pcm_dither_24 *dither)
+pcm_dither_24_init(struct pcm_dither *dither)
 {
 	dither->error[0] = dither->error[1] = dither->error[2] = 0;
 	dither->random = 0;
 }
 
 void
-pcm_dither_24_to_16(struct pcm_dither_24 *dither,
+pcm_dither_24_to_16(struct pcm_dither *dither,
 		    int16_t *dest, const int32_t *src,
 		    unsigned num_samples);
 
diff --git a/src/pcm_format.c b/src/pcm_format.c
index 0e0b2dfce..205966a6e 100644
--- a/src/pcm_format.c
+++ b/src/pcm_format.c
@@ -33,7 +33,7 @@ pcm_convert_8_to_16(int16_t *out, const int8_t *in,
 }
 
 static void
-pcm_convert_24_to_16(struct pcm_dither_24 *dither,
+pcm_convert_24_to_16(struct pcm_dither *dither,
 		     int16_t *out, const int32_t *in,
 		     unsigned num_samples)
 {
@@ -41,7 +41,7 @@ pcm_convert_24_to_16(struct pcm_dither_24 *dither,
 }
 
 const int16_t *
-pcm_convert_to_16(struct pcm_buffer *buffer, struct pcm_dither_24 *dither,
+pcm_convert_to_16(struct pcm_buffer *buffer, struct pcm_dither *dither,
 		  uint8_t bits, const void *src,
 		  size_t src_size, size_t *dest_size_r)
 {
diff --git a/src/pcm_format.h b/src/pcm_format.h
index 32279faef..53547df5d 100644
--- a/src/pcm_format.h
+++ b/src/pcm_format.h
@@ -23,14 +23,14 @@
 #include <stddef.h>
 
 struct pcm_buffer;
-struct pcm_dither_24;
+struct pcm_dither;
 
 /**
  * Converts PCM samples to 16 bit.  If the source format is 24 bit,
  * then dithering is applied.
  *
  * @param buffer a pcm_buffer object
  * @param dither a pcm_dither_24 object for 24-to-16 conversion
  * @param bits the number of in the source buffer
  * @param src the source PCM buffer
  * @param src_size the size of #src in bytes
@@ -38,7 +38,7 @@ struct pcm_dither_24;
  * @return the destination buffer
  */
 const int16_t *
-pcm_convert_to_16(struct pcm_buffer *buffer, struct pcm_dither_24 *dither,
+pcm_convert_to_16(struct pcm_buffer *buffer, struct pcm_dither *dither,
 		  uint8_t bits, const void *src,
 		  size_t src_size, size_t *dest_size_r);
 
@@ -46,7 +46,6 @@ pcm_convert_to_16(struct pcm_buffer *buffer, struct pcm_dither_24 *dither,
  * Converts PCM samples to 24 bit (32 bit alignment).
  *
  * @param buffer a pcm_buffer object
- * @param dither a pcm_dither_24 object for 24-to-16 conversion
  * @param bits the number of in the source buffer
  * @param src the source PCM buffer
  * @param src_size the size of #src in bytes
@@ -23,14 +23,14 @@
  *
  * @param buffer a pcm_buffer object
- * @param dither a pcm_dither_24 object for 24-to-16 conversion
+ * @param dither a pcm_dither object for 24-to-16 conversion
  * @param bits the number of in the source buffer
  * @param src the source PCM buffer